| Package: |
| pastis |
| Type: |
| Package |
| Version: |
| 0.1-2 |
| Date: |
| 2013-9-11 |
| Depends: |
| caper (>= 0.5.0), ape (>= 3.0.0) |
| Encoding: |
| UTF-8 |
| License: |
| GPL (>= 3) |
| LazyLoad: |
| yes |
A pre-processor for mrBayes that assimilates sequences, taxonomic information and tree constraints. The main functions of interest for most users will be pastis_simple, pastis_main and conch. The main analysis is conducted with pastis_simple or pastis_main followed by a manual execution of mrBayes (>3.2). The placement of taxa not contained in the tree constraint can be investigated using conch.